from metabolights_utils.provider.ftp import (default_ftp_client,
                                             folder_metadata_collector, model)

__all__ = [
    "default_ftp_client",
    "folder_metadata_collector",
    "model",
]



import logging

from metabolights_utils.isatab.default.assay_file import DefaultAssayFileReader
from metabolights_utils.isatab.default.assignment_file import \
    DefaultAssignmentFileReader
from metabolights_utils.isatab.default.investigation_file import (
    DefaultInvestigationFileReader, DefaultInvestigationFileWriter)
from metabolights_utils.isatab.default.sample_file import \
    DefaultSampleFileReader
from metabolights_utils.isatab.default.writer import DefaultIsaTableFileWriter
from metabolights_utils.isatab.reader import (InvestigationFileReader,
                                              IsaTableFileReader,
                                              IsaTabReaderFactory)
from metabolights_utils.isatab.writer import (InvestigationFileWriter,
                                              IsaTableFileWriter,
                                              IsaTabWriterFactory)

logger = logging.getLogger(__name__)


class DefaultIsaTabReaderFactory(IsaTabReaderFactory):
    def get_investigation_file_reader(self) -> InvestigationFileReader:
        logger.debug("Return default investigation file reader.")
        return DefaultInvestigationFileReader()

    def get_assay_file_reader(self, results_per_page=100) -> IsaTableFileReader:
        logger.debug("Return default assay file reader.")
        return DefaultAssayFileReader(results_per_page=results_per_page)

    def get_sample_file_reader(self, results_per_page=100) -> IsaTableFileReader:
        logger.debug("Return default sample file reader.")
        return DefaultSampleFileReader(results_per_page=results_per_page)

    def get_assignment_file_reader(self, results_per_page=100) -> IsaTableFileReader:
        logger.debug("Return default maf file reader.")
        return DefaultAssignmentFileReader(results_per_page=results_per_page)


class DefaultIsaTabWriterFactory(IsaTabWriterFactory):
    def get_investigation_file_writer(self) -> InvestigationFileWriter:
        logger.debug("Return default investigation file writer.")
        return DefaultInvestigationFileWriter()

    def get_assay_file_writer(self) -> IsaTableFileWriter:
        logger.debug("Return default ISA table file writer for assay file.")
        return DefaultIsaTableFileWriter()

    def get_sample_file_writer(self) -> IsaTableFileWriter:
        logger.debug("Return default ISA table file writer for sample file.")
        return DefaultIsaTableFileWriter()

    def get_assignment_file_writer(self) -> IsaTableFileWriter:
        logger.debug("Return default ISA table file writer for maf file.")
        return DefaultIsaTableFileWriter()



from metabolights_utils.tsv.actions import (add_column, add_row, base,
                                            copy_column, copy_row,
                                            delete_column, delete_row,
                                            move_column, move_row, update_cell,
                                            update_column,
                                            update_column_header, update_row)

__all__ = [
    "add_column",
    "add_row",
    "base",
    "copy_column",
    "copy_row",
    "delete_column",
    "delete_row",
    "move_column",
    "move_row",
    "update_cell",
    "update_column_header",
    "update_column",
    "update_row",
]



from metabolights_utils.isatab.default import (assay_file, assignment_file,
                                               base_isa_file,
                                               base_isa_table_file, factory,
                                               investigation_file, parser,
                                               sample_file, writer)

__all__ = [
    "parser",
    "assay_file",
    "assignment_file",
    "base_isa_table_file",
    "base_isa_file",
    "factory",
    "investigation_file",
    "sample_file",
    "writer",
]



from metabolights_utils.provider import (async_provider, definitions, ftp,
                                         ftp_repository,
                                         local_folder_metadata_collector,
                                         study_provider, submission_model,
                                         submission_repository, utils)

__all__ = [
    "ftp",
    "async_provider",
    "definitions",
    "ftp_repository",
    "local_folder_metadata_collector",
    "study_provider",
    "submission_model",
    "submission_repository",
    "utils",
]



from metabolights_utils.utils import (audit_utils, filename_utils, hash_utils,
                                      search_utils)

__all__ = [
    "audit_utils",
    "filename_utils",
    "hash_utils",
    "search_utils",
]



from metabolights_utils.isatab.default.parser import (common,
                                                      investigation_parser,
                                                      isa_table_parser)

__all__ = [
    "common",
    "investigation_parser",
    "isa_table_parser",
]



from metabolights_utils.models.isa import (assay_file, assignment_file, common,
                                           enums, investigation_file,
                                           samples_file)

__all__ = [
    "assay_file",
    "assignment_file",
    "common",
    "enums",
    "investigation_file",
    "samples_file",
]
